window.Gleam.initSearch([{"doc":"glaml","title":"glaml","content":"# glaml\n\n[![Package Version](https://img.shields.io/hexpm/v/glaml)](https://hex.pm/packages/glaml)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glaml/)\n\nGlaml is a simple Gleam wrapper around [yamerl](https://hex.pm/packages/yamerl) that enables your app to read YAML.\n\n```gleam\nimport glaml\n\n// ...\n\nlet assert Ok([doc]) = glaml.parse_string(&quot;\nstars: 7\nthis-is-nil:\njobs:\n  - being a cat\n&quot;)\n\nglaml.select_sugar(glaml.document_root(doc), &quot;jobs.#0&quot;)\n// -&gt; Ok(NodeStr(&quot;being a cat&quot;))\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glaml&gt;.\n\n## Instalation\n\nYou can add **glaml** to your project by simply running the command below.\n\n```sh\ngleam add glaml\n```\n\n## Development\n\n```sh\n./develop.sh # Copy Erlang headers (for lsp)\ngleam test   # Run the tests\n```\n","url":"index.html"},{"doc":"glaml","title":"Document","content":"pub type Document {\n  Document(root: Node)\n}\n A YAML document.&lt;br /&gt;\n To get the root `Node` call `document_root` on it, like this:\n\n \n let document = Document(root: NodeNil)\n let assert NodeNil = document_root(document)\n \n\nDocument(root: Node)\n\n\nSynonyms:\nglaml.Document\nglaml Document","url":"glaml.html#Document"},{"doc":"glaml","title":"Node","content":"pub type Node {\n  NodeNil\n  NodeStr(String)\n  NodeBool(Bool)\n  NodeInt(Int)\n  NodeFloat(Float)\n  NodeSeq(List(Node))\n  NodeMap(List(#(Node, Node)))\n}\n A YAML document node.\n\nNodeNil\n\n\nNodeStr(String)\n\n\nNodeBool(Bool)\n\n\nNodeInt(Int)\n\n\nNodeFloat(Float)\n\n\nNodeSeq(List(Node))\n\n\nNodeMap(List(#(Node, Node)))\n\n\nSynonyms:\nglaml.Node\nglaml Node","url":"glaml.html#Node"},{"doc":"glaml","title":"Selection","content":"pub type Selection {\n  SelectMap(key: Node)\n  SelectSeq(index: Int)\n}\n A `Node` selection used by `Selector`.\n\nSelectMap(key: Node)\n\n\nSelectSeq(index: Int)\n\n\nSynonyms:\nglaml.Selection\nglaml Selection","url":"glaml.html#Selection"},{"doc":"glaml","title":"Selector","content":"pub type Selector {\n  Selector(List(Selection))\n}\n A document selector that contains a sequence of selections leading to a `Node`.\n\nSelector(List(Selection))\n\n\nSynonyms:\nglaml.Selector\nglaml Selector","url":"glaml.html#Selector"},{"doc":"glaml","title":"SelectorError","content":"pub type SelectorError {\n  NodeNotFound(at: Int)\n  SelectorParseError\n}\n\nNodeNotFound(at: Int)\n\n\nSelectorParseError\n\n\nSynonyms:\nglaml.SelectorError\nglaml SelectorError","url":"glaml.html#SelectorError"},{"doc":"glaml","title":"YamlError","content":"pub type YamlError {\n  UnexpectedParsingError\n  ParsingError(msg: String, loc: YamlErrorLoc)\n}\n A YAML document error containing a message — `msg` and it&#39;s location — `loc`.\n\nUnexpectedParsingError\n\n\nParsingError(msg: String, loc: YamlErrorLoc)\n\n\nSynonyms:\nglaml.YamlError\nglaml YamlError","url":"glaml.html#YamlError"},{"doc":"glaml","title":"YamlErrorLoc","content":"pub type YamlErrorLoc {\n  YamlErrorLoc(line: Int, column: Int)\n}\n\nYamlErrorLoc(line: Int, column: Int)\n\n\nSynonyms:\nglaml.YamlErrorLoc\nglaml YamlErrorLoc","url":"glaml.html#YamlErrorLoc"},{"doc":"glaml","title":"document_root","content":"pub fn document_root(document: Document) -&gt; Node\n Gets the root `Node` of a YAML document.\n\n ## Examples\n\n \n let document = Document(root: NodeNil)\n let assert NodeNil = document_root(document)\n \n\nSynonyms:\nglaml.document_root\nglaml document_root","url":"glaml.html#document_root"},{"doc":"glaml","title":"parse_file","content":"pub fn parse_file(\n  path: String,\n) -&gt; Result(List(Document), YamlError)\n Parse a YAML file located in `path` into a list of YAML documents.\n\nSynonyms:\nglaml.parse_file\nglaml parse_file","url":"glaml.html#parse_file"},{"doc":"glaml","title":"parse_selector","content":"pub fn parse_selector(\n  selector: String,\n) -&gt; Result(Selector, SelectorError)\n Parses `selector` as a `Selector` and\n\nSynonyms:\nglaml.parse_selector\nglaml parse_selector","url":"glaml.html#parse_selector"},{"doc":"glaml","title":"parse_string","content":"pub fn parse_string(\n  string: String,\n) -&gt; Result(List(Document), YamlError)\n Parse a string into a list of YAML documents.\n\nSynonyms:\nglaml.parse_string\nglaml parse_string","url":"glaml.html#parse_string"},{"doc":"glaml","title":"select","content":"pub fn select(\n  from node: Node,\n  selector selector: Selector,\n) -&gt; Result(Node, SelectorError)\n Queries the given `node` with a `Selector`.\n\n ## Examples\n\n \n let map = NodeMap([\n   #(NodeStr(&quot;lib name&quot;), NodeStr(&quot;glaml&quot;)),\n   #(NodeStr(&quot;stars&quot;), NodeInt(7)),\n ])\n\n let assert Ok(NodeInt(7)) = select(from: map, selector: Selector([SelectMap(NodeStr(&quot;stars&quot;))]))\n \n\nSynonyms:\nglaml.select\nglaml select","url":"glaml.html#select"},{"doc":"glaml","title":"select_sugar","content":"pub fn select_sugar(\n  from node: Node,\n  selector selector: String,\n) -&gt; Result(Node, SelectorError)\n Parses the `selector` and queries the given `node` with it.\n\n ## Examples\n\n \n let map = NodeMap([\n   #(NodeStr(&quot;list&quot;), NodeMap([\n     #(NodeStr(&quot;elements&quot;), NodeSeq([NodeInt(101)]))\n   ])),\n   #(NodeStr(&quot;linked&quot;), NodeBool(False)),\n ])\n\n let assert Ok(NodeInt(101)) = select_sugar(from: map, selector: &quot;list.elements.#0&quot;)\n \n\nSynonyms:\nglaml.select_sugar\nglaml select_sugar","url":"glaml.html#select_sugar"},{"doc":"glaml","title":"glaml","content":"","url":"glaml.html"}]);